@@ -1,10 +1,14 @@
 from optparse import OptionParser
-from classDef import ReadData
 from classDef import Parameters
 
 
 def opt_parser(argv):
-    parser = OptionParser()
+    usage = ["Basic usage: %prog -c chip_files -i input_files -f file_type",
+             "You could also use a parameter file by: %prog -p param_file",
+             "For pre-processing only (parameter estimation), run: PePr-preprocess",
+             "For post-processing, run: PePr-postprocess"]
+    usage = '\n'.join(usage)
+    parser = OptionParser(usage=usage)
     parser.add_option(
             "-p", "--parameter-file", action="store", type="string",
             dest="parameter", default="",
@@ -29,12 +33,12 @@ def opt_parser(argv):
             metavar="INPUT2")
     parser.add_option(
             "-f", "--file-format", action="store", type="string",
-            dest="file_format",
-            help="bed, sam, bam, eland_multi, eland_extended, bowtie...",
+            dest="file_format",default="NA",
+            help="bed, sam, bam, sampe, bampe...",
             metavar="FORMAT")
     parser.add_option(
             "-s", "--shiftsize", action="store",
-            type="string", dest="shift_size", default="-1",
+            type="int", dest="shift_size", default=-1,
             help="Half the fragment size.", metavar="SHIFTSIZE")
     parser.add_option(
             "-w", "--windowsize", action="store",
@@ -50,10 +54,6 @@ def opt_parser(argv):
             type="string", dest="name", default = "NA",
             help = "the experimental name. NA if none provided",
             metavar="NAME")
-    parser.add_option(
-            "-r", "--remove_duplicate", action ="store_true",
-            dest = "remove_redundant", default=False,
-            help="Remove duplicated reads")
     parser.add_option(
             "--threshold", action ="store",
             type='float', dest="threshold", default=1e-5,
@@ -63,44 +63,56 @@ def opt_parser(argv):
             type="string", dest="peaktype", default="broad",
             help="sharp or broad. Default broad.")
     parser.add_option(
-            "--remove_artefacts", action="store_true",
-            dest="remove_artefacts", default=False,
-            help = 'Remove PCR-duplication peaks in post-procesing')
+            "--num-processors", action="store",
+            type="int", dest="num_procs", default =1,
+            help="number of cores for use.")
     parser.add_option(
-            "--narrow_peak_width", action="store_true",
-            dest ="narrow_peak_width", default=False,
-            help = '''Narrow peak width to contain the most
-            enriched regions. Only available for SHARP peak type''')
+            "--input-directory", action="store",
+            type="string", dest="input_directory", default='',
+            help="where the data files are. Absolute path recommended.")
     parser.add_option(
-            "--custom_normalization", action="store",
-            type="string", dest="normalization", default="YES", 
-            help='''You can choose not to normalize the reads by 
-            specifying 'NO' or provide your own normalization 
-            constants separated by commas.''')
+            "--output-directory", action="store",
+            type="string", dest="output_directory", default='',
+            help="where you want the output files to be")
     parser.add_option(
+            "--normalization", action="store",
+            type="string", dest="normalization", default="", 
+            help='''Normalization method. inter-group, intra-group, scale or no. Must manually specify for differential binding analysis.''')
+    parser.add_option(
+            "--keep-max-dup", action="store",
+            type="int", dest="keep_max_dup", default=-1,
+            help='''maximum number of duplicated reads to keep
+            if not specified, will not remove any duplicate.''')
+    '''parser.add_option(
             "--no_log", action="store_true",
             dest = "unsave_log", default=False,
             help = "Disable saving the log files")
+    '''
+    parser.add_option(
+            "--version", action="store_true",
+            dest="version",default=False,
+            help="Show version information and exit")
+
     (opt, args)=parser.parse_args(argv)
     if len(argv)==1:
         parser.print_help()
         exit(1)
+    if opt.version == True:
+        from  __init__ import __version__
+        print "PePr "+ __version__
+        exit(1)
+
     return opt
 
 def process_opt(opt):
     ''' validate the parameters that the user specified'''
     # initial process the filenames.
-    opt.chip1 = opt.chip1.strip().split(',')
-    opt.chip2 = opt.chip2.strip().split(',')
-    opt.input1 = opt.input1.strip().split(',')
-    opt.input2 = opt.input2.strip().split(',')
+    opt.chip1 = [] if opt.chip1 is '' else opt.chip1.strip().split(',') 
+    opt.chip2 = [] if opt.chip2 is '' else opt.chip2.strip().split(',')
+    opt.input1 = [] if opt.input1 is '' else opt.input1.strip().split(',')
+    opt.input2 = [] if opt.input2 is '' else opt.input2.strip().split(',')
+    opt.normalization = opt.normalization.lower()
     parameter = Parameters(opt)
 
-    ## initialize the data structure
-    read_data = ReadData(
-        opt.chip1, opt.input1,
-        opt.chip2, opt.input2,
-        parameter.difftest
-        )
     #add shift size validations
-    return parameter, read_data
+    return parameter
